#
# spec file for package suse-module-tools
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           suse-module-tools
Version:        12.4
Release:        3.2
Requires:       /sbin/depmod
Requires:       /sbin/mkinitrd
Requires:       findutils
Requires:       gzip
# for grepping /etc/SUSE-release
PreReq:         grep
# nm and rpmsort (rpm) are required by the weak-modules script which is invoked
# in post, it also requires getopt (coreutils) and sed
PreReq:         coreutils rpm
# XXX: this should be nm OR eu-nm, the script works with both
PreReq:         /usr/bin/eu-nm /bin/sed
Summary:        Configuration for module loading and SUSE-specific utilities for KMPs
License:        GPL-2.0+
Group:          System/Base
Source:         README.SUSE
Source2:        modprobe.conf.tar.bz2
Source3:        depmod-00-system.conf
Source4:        10-unsupported-modules.conf
Source5:        weak-modules
Source6:        weak-modules2
Source7:        driver-check.sh
Source8:        suse-module-tools.rpmlintrc
Source9:        modsign-verify
Source10:       kmp-install
Source11:       macros.initrd
Source12:       regenerate-initrd-posttrans
Source13:       50-kernel-uname_r.conf
Source14:       modhash
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains helper scripts for KMP installation and
uninstallation, as well as default configuration files for depmod and
modprobe. These utilities are provided by kmod-compat or
module-init-tools, whichever implementation you choose to install.

%prep
%setup -Tcqa2

%build

%install
b="%buildroot"
mkdir -p "$b/%_docdir/module-init-tools"
install -pm644 "%_sourcedir/README.SUSE" "$b/%_docdir/module-init-tools" 
#
# now assemble the parts for modprobe.conf
#
cd modprobe.conf
cp modprobe.conf.common 00-system.conf
if [ -f "modprobe.conf.$RPM_ARCH" ]; then
	cat "modprobe.conf.$RPM_ARCH" >>00-system.conf
fi
install -d -m 755 "$b/etc/modprobe.d"
install -pm644 "%_sourcedir/10-unsupported-modules.conf" \
	"$b/etc/modprobe.d/"
install -pm644 00-system.conf "$b/etc/modprobe.d/"
install -pm644 modprobe.conf.local "$b/etc/modprobe.d/99-local.conf"
install -d -m 755 "$b/etc/depmod.d"
install -pm 644 "%_sourcedir/depmod-00-system.conf" \
	"$b/etc/depmod.d/00-system.conf"

# "module-init-tools" name hardcoded in KMPs, mkinitrd, etc.
install -d -m 755 "$b/usr/lib/module-init-tools"
install -pm 755 %_sourcedir/weak-modules{,2} "$b/usr/lib/module-init-tools/"
install -pm 755 %_sourcedir/driver-check.sh "$b/usr/lib/module-init-tools/"

# rpm macros and helper
install -d -m 755 "$b/etc/rpm"
install -pm 644 "%_sourcedir/macros.initrd" "$b/etc/rpm/"
install -pm 755 "%_sourcedir/regenerate-initrd-posttrans" "$b/usr/lib/module-init-tools/"

# modsign-verify for verifying module signatures
install -d -m 755 "$b/usr/bin"
install -pm 755 %_sourcedir/modsign-verify "$b/usr/bin/"
install -pm 755 %_sourcedir/kmp-install "$b/usr/bin/"
# modhash for calculating hash of signed kernel module
install -pm 755 %_sourcedir/modhash "$b/usr/bin/"

# systemd service to load /boot/sysctl.conf-`uname -r`
install -d -m 755 "$b/usr/lib/systemd/system/systemd-sysctl.service.d"
install -pm 644 %_sourcedir/50-kernel-uname_r.conf "$b/usr/lib/systemd/system/systemd-sysctl.service.d"

%post
test_allow_on_install()
{
	# configure handling of unsupported modules
	# default is to allow them
	allow=1
	# if the obsolete LOAD_UNSUPPORTED_MODULES_AUTOMATICALLY variable is
	# set to no, don't allow (this was used in SLES 9 and 10)
	if test -e /etc/sysconfig/hardware/config; then
		. /etc/sysconfig/hardware/config
		if test "x$LOAD_UNSUPPORTED_MODULES_AUTOMATICALLY" = "xno"; then
			allow=0
		fi
		# obsolete
		rm /etc/sysconfig/hardware/config
	fi
	# don't change the setting during upgrade
	if test "$1" != 1; then
		return
	fi
	# on SLES, the default is not to allow unsupported modules
	if grep -qs "Enterprise Server" /etc/SuSE-release; then
		allow=0
	else
		return
	fi
	# unless the admin passed "oem-modules=1" to the kernel during install
	if grep -qs '\<oem-modules=1\>' /proc/cmdline; then
		allow=1
		return
	fi
	# or if the installer already loaded some unsupported modules
	# (see TAINT_NO_SUPPORT in /usr/src/linux/include/linux/kernel.h)
	tainted=$(cat /proc/sys/kernel/tainted 2>/dev/null || echo 0)
	if test $((tainted & (1<<30))) != 0; then
		allow=1
		return
	fi
}
# upgrade from old locations
if test -e /etc/modprobe.d/unsupported-modules; then
	mv -f /etc/modprobe.d/unsupported-modules \
		/etc/modprobe.d/10-unsupported-modules.conf
fi
if test -e /etc/modprobe.conf.local; then
	mv -f /etc/modprobe.conf.local \
		/etc/modprobe.d/99-local.conf
fi
test_allow_on_install "$@"
if test "$allow" = "0"; then
	sed -ri 's/^( *allow_unsupported_modules *) 1/\1 0/' \
		/etc/modprobe.d/10-unsupported-modules.conf
fi

%files
%defattr(-,root,root)
%dir               /etc/modprobe.d
%config            /etc/modprobe.d/00-system.conf
%config(noreplace) /etc/modprobe.d/10-unsupported-modules.conf
%config(noreplace) /etc/modprobe.d/99-local.conf
%dir               /etc/depmod.d
%config            /etc/depmod.d/00-system.conf
%config /etc/rpm/macros.initrd
%_docdir/module-init-tools
/usr/bin/modhash
/usr/bin/kmp-install
/usr/bin/modsign-verify
/usr/lib/module-init-tools
/usr/lib/systemd/system/systemd-sysctl.service.d

%changelog
* Fri Jul 22 2016 jbohac@suse.cz
- softdep of bridge on br_netfilter (bsc#937216)
* Fri May 27 2016 mmarek@suse.cz
- Run dos2unix on the modhash script.
* Thu May 26 2016 jlee@suse.com
- Add modhash tool to calculate hash of signed module.
  It strips X.509 or PKCS#7 signature before hash kernel module.
  (fate#319460)
* Wed May 25 2016 mmarek@suse.cz
- Remove -x bit from 50-kernel-uname_r.conf (bsc#981291).
* Fri Apr 29 2016 mmarek@suse.cz
- Ignore failures when loading the kernel sysctl (bsc#977715).
* Thu Apr 28 2016 mmarek@suse.com
- Add a systemd service to load /boot/sysctl.conf-`uname -r`
  (bsc#977715).
* Fri Apr  1 2016 mmarek@suse.cz
- Skip KMPs built from the kernel spec file directly (fate#319339)
- Bump version number to 12.4
* Tue Feb 23 2016 lnussel@suse.de
- add missing requirements on module-init-tools, findutils and gzip,
  mkinitrd (bnc#965830)
* Fri Jan 15 2016 bpoirier@suse.com
- Add module option ib_mthca.catas_reset_disable=1 on ppc64le (bsc#456389).
* Tue Oct 13 2015 mmarek@suse.cz
- Revert change for fate#319339, as some 3rd party KMPs are built
  with a modified template (bsc#949862).
* Tue Sep  8 2015 trenn@suse.de
- Use /run instead of deprecated /var/run
  This can have sever consequences if this package uses /var/run. It may
  be installed before filesystem package generating the /run tmpfs and
  predict it to generate the link /var/run -> /run. Later dracut convertfs
  kicks in to generate it, but it has issues. bsc#922676
* Thu Aug 13 2015 mmarek@suse.cz
- Only handle KMPs that are built using the %%kernel_module_package
  macro (preparatory work for fate#319339).
* Tue Jun 23 2015 mmarek@suse.cz
- Use absolute path to mkinitrd (bsc#935566)
* Fri May 16 2014 mmarek@suse.cz
- Add kgraft/ to the depmod search list (fate#313296)
* Mon May  5 2014 tonyj@suse.com
- Add support for ARM zImage to weak-modules2
* Tue Apr 15 2014 mmarek@suse.cz
- weak-modules2: Use lsinitrd to list the modules in an initrd, so
  that initrds with early microcode work (bnc#873209, bnc#873113).
* Fri Apr  4 2014 mmarek@suse.cz
- weak-modules2: Run mkinitrd in posttrans if $INITRD_IN_POSTTRANS
  is set (fate#313506)
* Fri Apr  4 2014 mmarek@suse.cz
- regenerate-initrd-posttrans: Run mkinitrd_setup
* Fri Apr  4 2014 mmarek@suse.cz
- Add macros for regenerating the initrd in %%posttrans
  (fate#313506).
* Mon Mar 31 2014 mmarek@suse.cz
- Use softdep to order {u,o,e}hci-hcd drivers.
- Drop ia64 modprobe config.
* Fri Mar 28 2014 mmarek@suse.cz
- Add kmp-install tool for easier installation of SolidDriver KMPs
  (fate#314581).
* Tue Mar 11 2014 mmarek@suse.cz
- Add modsign-verify tool to verify signatures of modules
  (fate#314507).
* Tue Mar 11 2014 mmarek@suse.cz
- weak-modules2: Support XZ compressed initrds (bnc#778119,
  bnc#867312)
* Mon Mar 10 2014 mmarek@suse.cz
- The package cannot be noarch, because it installs different
  configs for different architectures.
- Install 10-unsupported-modules.conf unconditionally, kmod has
  been patched.
* Fri Feb  7 2014 rsalevsky@suse.com
- load the uas driver simulsimultaneously with the usb_storage driver and vice versa (bnc#862397)
* Wed May 29 2013 schwab@suse.de
- weak-modules{,2}: also look for Image-$krel for aarch64
* Sun Mar 17 2013 crrodriguez@opensuse.org
- The "allow_unsupported_modules" feature, does not belong too
  openSUSE, kmod (and hence udev and systemd) do not understand
  it in anyway. limit to SLE only.
* Wed Nov 14 2012 jengelh@inai.de
- New package. Split SUSE-specific scripts from module-init-tools,
  so that we can actually get a system with kmod-compat running.
